ActionStream<Chunk, Response> class
A stream of chunks emitted by an action, which also resolves to a final response.
- Inheritance
-
- Object
- Stream<
Chunk> - StreamView<
Chunk> - ActionStream
Constructors
-
ActionStream(Stream<
Chunk> stream) - Creates a new ActionStream from a Stream of chunks.
Properties
-
first
→ Future<
Chunk> -
The first element of this stream.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBroadcast → bool
-
Whether this stream is a broadcast stream.
no setterinherited
-
isEmpty
→ Future<
bool> -
Whether this stream contains any elements.
no setterinherited
-
last
→ Future<
Chunk> -
The last element of this stream.
no setterinherited
-
length
→ Future<
int> -
The number of elements in this stream.
no setterinherited
-
onResult
→ Future<
Response> -
A future that resolves to the final response of the action once the stream is complete.
no setter
- result → Response
-
The final response of the action, throws an error if the stream has not completed yet.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
single
→ Future<
Chunk> -
The single element of this stream.
no setterinherited
Methods
-
any(
bool test(Chunk element)) → Future< bool> -
Checks whether
testaccepts any element provided by this stream.inherited -
asBroadcastStream(
{void onListen(StreamSubscription< Chunk> subscription)?, void onCancel(StreamSubscription<Chunk> subscription)?}) → Stream<Chunk> -
Returns a multi-subscription stream that produces the same events as this.
inherited
-
asyncExpand<
E> (Stream< E> ? convert(Chunk event)) → Stream<E> -
Transforms each element into a sequence of asynchronous events.
inherited
-
asyncMap<
E> (FutureOr< E> convert(Chunk event)) → Stream<E> -
Creates a new stream with each data event of this stream asynchronously
mapped to a new event.
inherited
-
cast<
R> () → Stream< R> -
Adapt this stream to be a
Stream<R>.inherited -
contains(
Object? needle) → Future< bool> -
Returns whether
needleoccurs in the elements provided by this stream.inherited -
distinct(
[bool equals(Chunk previous, Chunk next)?]) → Stream< Chunk> -
Skips data events if they are equal to the previous data event.
inherited
-
drain<
E> ([E? futureValue]) → Future< E> -
Discards all data on this stream, but signals when it is done or an error
occurred.
inherited
-
elementAt(
int index) → Future< Chunk> -
Returns the value of the
indexth data event of this stream.inherited -
every(
bool test(Chunk element)) → Future< bool> -
Checks whether
testaccepts all elements provided by this stream.inherited -
expand<
S> (Iterable< S> convert(Chunk element)) → Stream<S> -
Transforms each element of this stream into a sequence of elements.
inherited
-
firstWhere(
bool test(Chunk element), {Chunk orElse()?}) → Future< Chunk> -
Finds the first element of this stream matching
test.inherited -
fold<
S> (S initialValue, S combine(S previous, Chunk element)) → Future< S> -
Combines a sequence of values by repeatedly applying
combine.inherited -
forEach(
void action(Chunk element)) → Future< void> -
Executes
actionon each element of this stream.inherited -
handleError(
Function onError, {bool test(dynamic error)?}) → Stream< Chunk> -
Creates a wrapper Stream that intercepts some errors from this stream.
inherited
-
join(
[String separator = ""]) → Future< String> -
Combines the string representation of elements into a single string.
inherited
-
lastWhere(
bool test(Chunk element), {Chunk orElse()?}) → Future< Chunk> -
Finds the last element in this stream matching
test.inherited -
listen(
void onData(Chunk value)?, {Function? onError, void onDone()?, bool? cancelOnError}) → StreamSubscription< Chunk> -
Adds a subscription to this stream.
inherited
-
map<
S> (S convert(Chunk event)) → Stream< S> -
Transforms each element of this stream into a new stream event.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pipe(
StreamConsumer< Chunk> streamConsumer) → Future -
Pipes the events of this stream into
streamConsumer.inherited -
reduce(
Chunk combine(Chunk previous, Chunk element)) → Future< Chunk> -
Combines a sequence of values by repeatedly applying
combine.inherited -
setError(
Object error, StackTrace st) → void - Sets an error on the action stream and completes the future with an error.
-
setResult(
Response result) → void - Sets the final result of the action stream and completes the future.
-
singleWhere(
bool test(Chunk element), {Chunk orElse()?}) → Future< Chunk> -
Finds the single element in this stream matching
test.inherited -
skip(
int count) → Stream< Chunk> -
Skips the first
countdata events from this stream.inherited -
skipWhile(
bool test(Chunk element)) → Stream< Chunk> -
Skip data events from this stream while they are matched by
test.inherited -
take(
int count) → Stream< Chunk> -
Provides at most the first
countdata events of this stream.inherited -
takeWhile(
bool test(Chunk element)) → Stream< Chunk> -
Forwards data events while
testis successful.inherited -
timeout(
Duration timeLimit, {void onTimeout(EventSink< Chunk> sink)?}) → Stream<Chunk> -
Creates a new stream with the same events as this stream.
inherited
-
toList(
) → Future< List< Chunk> > -
Collects all elements of this stream in a List.
inherited
-
toSet(
) → Future< Set< Chunk> > -
Collects the data of this stream in a Set.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transform<
S> (StreamTransformer< Chunk, S> streamTransformer) → Stream<S> -
Applies
streamTransformerto this stream.inherited -
where(
bool test(Chunk event)) → Stream< Chunk> -
Creates a new stream from this stream that discards some elements.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited