SessionStore class abstract interface

Interface for persistent session snapshot storage.

Implementers
Annotations
  • @experimental

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getSnapshot({String? snapshotId, String? sessionId, Map<String, dynamic>? context}) → Future<SessionSnapshot?>
Loads a snapshot either by its snapshotId or by sessionId.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveSnapshot(String? snapshotId, SnapshotMutator mutator, {Map<String, dynamic>? context}) → Future<String?>
Atomically reads the current snapshot (if snapshotId is provided), passes it to mutator, and persists the result.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited