parentSnapshotId property

String? parentSnapshotId
final

The id of the parent snapshot this turn continues from, or null on the first turn of a fresh session.

Implementation

final String? parentSnapshotId;