$AgentMetadata class abstract

Annotations
  • @Schema.new()

Constructors

$AgentMetadata()

Properties

abortable → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateManagement → AgentStateManagement
no setter
stateSchema → Map<String, dynamic>?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited