$JsonPatchOperation class abstract

Annotations
  • @Schema.new()

Constructors

$JsonPatchOperation()

Properties

from → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
op → JsonPatchOp
no setter
path → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Object?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited