AgentAbortRequest class base

Constructors

AgentAbortRequest({required String snapshotId})
AgentAbortRequest.fromJson(Map<String, dynamic> json)
Creates a AgentAbortRequest from a JSON map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotId ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this AgentAbortRequest to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<AgentAbortRequest>
The JSON schema and type descriptor for AgentAbortRequest.