AgentError<State> class final

Thrown when a turn fails. Carries the last-good state so the session is recoverable.

Implemented types

Constructors

AgentError({required String message, required String status, Object? details, State? state, String? snapshotId, required AgentResponse<State> response})

Properties

details → Object?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
response → AgentResponse<State>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotId → String?
final
state → State?
final
status → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited