AgentInput class base

Constructors

AgentInput({bool? detach, Message? message, AgentResume? resume})
AgentInput.fromJson(Map<String, dynamic> json)
Creates a AgentInput from a JSON map.
factory

Properties

detach ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ Message?
getter/setter pair
resume ↔ AgentResume?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this AgentInput to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<AgentInput>
The JSON schema and type descriptor for AgentInput.