AgentResult class base

Constructors

AgentResult({Message? message, List<Artifact>? artifacts, AgentFinishReason? finishReason})
AgentResult.fromJson(Map<String, dynamic> json)
Creates a AgentResult from a JSON map.
factory

Properties

artifacts ↔ List<Artifact>?
getter/setter pair
finishReason ↔ AgentFinishReason?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ Message?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this AgentResult to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<AgentResult>
The JSON schema and type descriptor for AgentResult.