AgentResume class base

Constructors

AgentResume({List<ToolResponsePart>? respond, List<ToolRequestPart>? restart})
AgentResume.fromJson(Map<String, dynamic> json)
Creates a AgentResume from a JSON map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
respond ↔ List<ToolResponsePart>?
getter/setter pair
restart ↔ List<ToolRequestPart>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this AgentResume to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<AgentResume>
The JSON schema and type descriptor for AgentResume.