AgentStreamChunk class base

Constructors

AgentStreamChunk({ModelResponseChunk? modelChunk, List<JsonPatchOperation>? customPatch, Artifact? artifact, TurnEnd? turnEnd})
AgentStreamChunk.fromJson(Map<String, dynamic> json)
Creates a AgentStreamChunk from a JSON map.
factory

Properties

artifact ↔ Artifact?
getter/setter pair
customPatch ↔ List<JsonPatchOperation>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
modelChunk ↔ ModelResponseChunk?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
turnEnd ↔ TurnEnd?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this AgentStreamChunk to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<AgentStreamChunk>
The JSON schema and type descriptor for AgentStreamChunk.