Artifact class base

Constructors

Artifact({String? name, required List<Part> parts, Map<String, dynamic>? metadata})
Artifact.fromJson(Map<String, dynamic> json)
Creates a Artifact from a JSON map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, dynamic>?
getter/setter pair
name ↔ String?
getter/setter pair
parts ↔ List<Part>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Artifact to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<Artifact>
The JSON schema and type descriptor for Artifact.