JsonPatchOperation class base

Constructors

JsonPatchOperation({required JsonPatchOp op, required String path, String? from, Object? value})
JsonPatchOperation.fromJson(Map<String, dynamic> json)
Creates a JsonPatchOperation from a JSON map.
factory

Properties

from ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
op ↔ JsonPatchOp
getter/setter pair
path ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ Object?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this JsonPatchOperation to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<JsonPatchOperation>
The JSON schema and type descriptor for JsonPatchOperation.