SessionSnapshot class base

Constructors

SessionSnapshot({required String snapshotId, String? sessionId, String? parentId, required String createdAt, String? updatedAt, String? heartbeatAt, SnapshotStatus? status, AgentFinishReason? finishReason, AgentErrorInfo? error, SessionState? state})
SessionSnapshot.fromJson(Map<String, dynamic> json)
Creates a SessionSnapshot from a JSON map.
factory

Properties

createdAt ↔ String
getter/setter pair
error ↔ AgentErrorInfo?
getter/setter pair
finishReason ↔ AgentFinishReason?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
heartbeatAt ↔ String?
getter/setter pair
parentId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId ↔ String?
getter/setter pair
snapshotId ↔ String
getter/setter pair
state ↔ SessionState?
getter/setter pair
status ↔ SnapshotStatus?
getter/setter pair
updatedAt ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this SessionSnapshot to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<SessionSnapshot>
The JSON schema and type descriptor for SessionSnapshot.