$AgentInput class abstract

Annotations
  • @Schema.new()

Constructors

$AgentInput()

Properties

detach → bool?
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → $Message?
no setter
resume → $AgentResume?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited