$AgentOutput class abstract

Annotations
  • @Schema.new()

Constructors

$AgentOutput()

Properties

artifacts List<$Artifact>?
no setter
error $AgentErrorInfo?
no setter
finishReason AgentFinishReason?
no setter
hashCode int
The hash code for this object.
no setterinherited
message $Message?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
no setter
snapshotId String?
no setter
state $SessionState?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited