$AgentStreamChunk class abstract

Annotations
  • @Schema.new()

Constructors

$AgentStreamChunk()

Properties

artifact $Artifact?
no setter
customPatch List<$JsonPatchOperation>?
no setter
hashCode int
The hash code for this object.
no setterinherited
modelChunk $ModelResponseChunk?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
turnEnd $TurnEnd?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited