$EvalFnResponse class abstract

Annotations
  • @Schema.new()

Constructors

$EvalFnResponse()

Properties

evaluation Object?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleIndex double?
no setter
spanId String?
no setter
testCaseId String
no setter
traceId String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited