$GetSnapshotDataInput class abstract

Annotations
  • @Schema.new()

Constructors

$GetSnapshotDataInput()

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadataOnly → bool?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → String?
no setter
snapshotId → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited