$ModelRequest class abstract

Annotations
  • @Schema.new()

Constructors

$ModelRequest()

Properties

config → Map<String, dynamic>?
no setter
docs → List<$DocumentData>?
no setter
hashCode → int
The hash code for this object.
no setterinherited
messages → List<$Message>
no setter
output → $OutputConfig?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolChoice → String?
no setter
tools → List<$ToolDefinition>?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited