$ModelResponseChunk class abstract

Annotations
  • @Schema.new()

Constructors

$ModelResponseChunk()

Properties

aggregated → bool?
no setter
content → List<$Part>
no setter
custom → Map<String, dynamic>?
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int?
no setter
role → Role?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited