$ReflectionRunActionParams class abstract
- Annotations
-
- @Schema.new()
Constructors
Properties
- context → dynamic
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- init → dynamic
-
no setter
- input → dynamic
-
no setter
- key → String
-
no setter
- runtimeId → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stream → bool?
-
no setter
- streamInput → bool?
-
no setter
-
telemetryLabels
→ Map<
String, dynamic> ? -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited