$ToolRequestPart class abstract

Implemented types
Annotations
  • @Schema.new()

Constructors

$ToolRequestPart()

Properties

custom → Map<String, dynamic>?
no setter
data → Map<String, dynamic>?
no setter
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, dynamic>?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolRequest → $ToolRequest
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited