Action<Input, Output, Chunk, Init> class

Inheritance
Implementers

Constructors

Action({required String name, required String actionType, required InternalActionFn<Input, Output, Chunk, Init> fn, SchemanticType<Input>? inputSchema, SchemanticType<Output>? outputSchema, SchemanticType<Chunk>? streamSchema, SchemanticType<Init>? initSchema, String? description, Map<String, dynamic>? metadata})

Properties

actionType String
finalinherited
description String?
finalinherited
fn → InternalActionFn<Input, Output, Chunk, Init>
final
hashCode int
The hash code for this object.
no setterinherited
initSchema → SchemanticType<Init>?
finalinherited
inputSchema → SchemanticType<Input>?
finalinherited
metadata Map<String, dynamic>
finalinherited
name String
finalinherited
outputSchema → SchemanticType<Output>?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamSchema → SchemanticType<Chunk>?
finalinherited

Methods

call(Input? input, {StreamingCallback<Chunk>? onChunk, Map<String, dynamic>? context, Stream<Input>? inputStream, Init? init, TraceStartCallback? onTraceStart}) Future<Output>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(Input? input, {StreamingCallback<Chunk>? onChunk, Map<String, dynamic>? context, Stream<Input>? inputStream, Init? init, TraceStartCallback? onTraceStart}) Future<RunResult<Output>>
runRaw(dynamic input, {StreamingCallback<Chunk>? onChunk, Map<String, dynamic>? context, Stream<Input>? inputStream, dynamic init, TraceStartCallback? onTraceStart}) Future<RunResult<Output>>
stream(Input? input, {Map<String, dynamic>? context, Stream<Input>? inputStream, Init? init}) ActionStream<Chunk, Output>
streamBidi({Stream<Input>? inputStream, StreamingCallback<Chunk>? onChunk, Map<String, dynamic>? context, Init? init}) → BidiActionStream<Chunk, Output, Input>
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited