ActionMetadata<Input, Output, Chunk, Init> class

Implementers

Constructors

ActionMetadata({required String name, String actionType = 'custom', String? description, SchemanticType<Input>? inputSchema, SchemanticType<Output>? outputSchema, SchemanticType<Chunk>? streamSchema, SchemanticType<Init>? initSchema, Map<String, dynamic>? metadata})

Properties

actionType String
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
initSchema → SchemanticType<Init>?
final
inputSchema → SchemanticType<Input>?
final
metadata Map<String, dynamic>
final
name String
final
outputSchema → SchemanticType<Output>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamSchema → SchemanticType<Chunk>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited