AgentInterrupt<Input, Output> class final

A single tool request a turn paused on. respond/restart are builders: they return the part to put into a resume payload; they do not send.

Constructors

AgentInterrupt(ToolRequestPart part)

Properties

hashCode int
The hash code for this object.
no setterinherited
input → Input
final
name String
final
ref String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
respond(Output output) ToolResponsePart
Builds a respond entry for this interrupt. Does not send.
restart([Map<String, dynamic>? resumed]) ToolRequestPart
Builds a restart entry re-issuing the original tool request.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited