AgentMetadata class base
Constructors
-
AgentMetadata({required AgentStateManagement stateManagement, required bool abortable, Map<
String, dynamic> ? stateSchema}) -
AgentMetadata.fromJson(Map<
String, dynamic> json) -
Creates a AgentMetadata from a JSON map.
factory
Properties
- abortable ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stateManagement ↔ AgentStateManagement
-
getter/setter pair
-
stateSchema
↔ Map<
String, dynamic> ? -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes this AgentMetadata to a JSON map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
$schema
→ const SchemanticType<
AgentMetadata> - The JSON schema and type descriptor for AgentMetadata.