BidiModel<CustomOptions> class

Inheritance

Constructors

BidiModel({required String name, required InternalActionFn<ModelRequest, ModelResponse, ModelResponseChunk, ModelRequest> fn, Map<String, dynamic>? metadata, SchemanticType<CustomOptions>? customOptions})

Properties

actionType String
finalinherited
customOptions ↔ SchemanticType<CustomOptions>?
getter/setter pair
description String?
finalinherited
fn → InternalActionFn<ModelRequest, ModelResponse, ModelResponseChunk, ModelRequest>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
initSchema → SchemanticType<ModelRequest>?
finalinherited
inputSchema → SchemanticType<ModelRequest>?
finalinherited
metadata Map<String, dynamic>
finalinherited
name String
finalinherited
outputSchema → SchemanticType<ModelResponse>?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamSchema → SchemanticType<ModelResponseChunk>?
finalinherited

Methods

call(ModelRequest? input, {StreamingCallback<ModelResponseChunk>? onChunk, Map<String, dynamic>? context, Stream<ModelRequest>? inputStream, ModelRequest? init, TraceStartCallback? onTraceStart}) Future<ModelResponse>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(ModelRequest? input, {StreamingCallback<ModelResponseChunk>? onChunk, Map<String, dynamic>? context, Stream<ModelRequest>? inputStream, ModelRequest? init, TraceStartCallback? onTraceStart}) Future<RunResult<ModelResponse>>
inherited
runRaw(dynamic input, {StreamingCallback<ModelResponseChunk>? onChunk, Map<String, dynamic>? context, Stream<ModelRequest>? inputStream, dynamic init, TraceStartCallback? onTraceStart}) Future<RunResult<ModelResponse>>
inherited
stream(ModelRequest? input, {Map<String, dynamic>? context, Stream<ModelRequest>? inputStream, ModelRequest? init}) ActionStream<ModelResponseChunk, ModelResponse>
inherited
streamBidi({Stream<ModelRequest>? inputStream, StreamingCallback<ModelResponseChunk>? onChunk, Map<String, dynamic>? context, ModelRequest? init}) → BidiActionStream<ModelResponseChunk, ModelResponse, ModelRequest>
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited