Candidate class base

Constructors

Candidate({required double index, required Message message, GenerationUsage? usage, required FinishReason finishReason, String? finishMessage, Map<String, dynamic>? custom})
Candidate.fromJson(Map<String, dynamic> json)
Creates a Candidate from a JSON map.
factory

Properties

custom Map<String, dynamic>?
getter/setter pair
finishMessage String?
getter/setter pair
finishReason FinishReason
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
index double
getter/setter pair
message Message
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usage GenerationUsage?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Candidate to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<Candidate>
The JSON schema and type descriptor for Candidate.