DetachedTask<State> class final

A handle to a background (detached) task.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshotId String
final

Methods

abort() Future<SnapshotStatus?>
Aborts the task.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
poll({Duration interval = const Duration(seconds: 1), int maxConsecutiveMisses = 10}) Stream<AgentSnapshot<State>>
Yields status until a terminal state.
toString() String
A string representation of this object.
inherited
wait({Duration interval = const Duration(seconds: 1)}) Future<AgentSnapshot<State>>
Resolves when the task reaches a terminal state.

Operators

operator ==(Object other) bool
The equality operator.
inherited