DocumentData class base

Constructors

DocumentData({required List<Part> content, Map<String, dynamic>? metadata})
DocumentData.fromJson(Map<String, dynamic> json)
Creates a DocumentData from a JSON map.
factory

Properties

content List<Part>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this DocumentData to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<DocumentData>
The JSON schema and type descriptor for DocumentData.