Embedding class base

Constructors

Embedding({required List<double> embedding, Map<String, dynamic>? metadata})
Embedding.fromJson(Map<String, dynamic> json)
Creates a Embedding from a JSON map.
factory

Properties

embedding ↔ List<double>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, dynamic>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Embedding to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<Embedding>
The JSON schema and type descriptor for Embedding.