EvalFnResponse class base

Constructors

EvalFnResponse({double? sampleIndex, required String testCaseId, String? traceId, String? spanId, EvalFnResponseEvaluation? evaluation})
EvalFnResponse.fromJson(Map<String, dynamic> json)
Creates a EvalFnResponse from a JSON map.
factory

Properties

evaluation ↔ Object?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleIndex ↔ double?
getter/setter pair
spanId ↔ String?
getter/setter pair
testCaseId ↔ String
getter/setter pair
traceId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this EvalFnResponse to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<EvalFnResponse>
The JSON schema and type descriptor for EvalFnResponse.