Flow<Input, Output, Chunk, Init> class base

Inheritance

Constructors

Flow({required String name, required ActionFn<Input, Output, Chunk, Init> fn, SchemanticType<Input>? inputSchema, SchemanticType<Output>? outputSchema, SchemanticType<Chunk>? streamSchema, SchemanticType<Init>? initSchema, Map<String, dynamic>? metadata})
Creates a unary flow.
Flow.bidi({required String name, required BidiActionFn<Input, Output, Chunk, Init> fn, SchemanticType<Input>? inputSchema, SchemanticType<Output>? outputSchema, SchemanticType<Chunk>? streamSchema, SchemanticType<Init>? initSchema, Map<String, dynamic>? metadata})
Creates a bidirectional flow whose function receives the input stream.

Properties

actionType → ActionType
finalinherited
description → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
initSchema → SchemanticType<Init>?
finalinherited
inputSchema → SchemanticType<Input>?
finalinherited
key → String?
The fully-qualified registry key (/$actionType/$name) or, for actions resolved through a dynamic action provider, the DAP key (/dynamic-action-provider/<host>:<actionType>/<name>).
no setterinherited
metadata → Map<String, dynamic>
finalinherited
name → String
finalinherited
outputSchema → SchemanticType<Output>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamSchema → SchemanticType<Chunk>?
finalinherited

Methods

call(Input? input, {StreamingCallback<Chunk>? onChunk, Map<String, dynamic>? context, Stream<Input>? inputStream, Init? init, TraceStartCallback? onTraceStart, CancellationToken? cancel}) → Future<Output>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(Input? input, {StreamingCallback<Chunk>? onChunk, Map<String, dynamic>? context, Stream<Input>? inputStream, Init? init, TraceStartCallback? onTraceStart, CancellationToken? cancel}) → Future<RunResult<Output>>
inherited
runRaw(dynamic input, {StreamingCallback<Chunk>? onChunk, Map<String, dynamic>? context, Stream<Input>? inputStream, dynamic init, TraceStartCallback? onTraceStart, CancellationToken? cancel}) → Future<RunResult<Output>>
inherited
stream(Input? input, {Map<String, dynamic>? context, Stream<Input>? inputStream, Init? init, CancellationToken? cancel}) → ActionStream<Chunk, Output>
inherited
streamBidi({Stream<Input>? inputStream, StreamingCallback<Chunk>? onChunk, Map<String, dynamic>? context, Init? init, CancellationToken? cancel}) → BidiActionStream<Chunk, Output, Input>
Starts a bidirectional session with this action: send inputs with BidiActionStream.send while consuming output chunks.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited