GenerateActionOutputConfig class base

Constructors

GenerateActionOutputConfig({String? format, String? contentType, GenerateActionOutputConfigInstructions? instructions, Map<String, dynamic>? jsonSchema, bool? constrained, bool? defaultInstructions})
GenerateActionOutputConfig.fromJson(Map<String, dynamic> json)
factory

Properties

constrained bool?
getter/setter pair
contentType String?
getter/setter pair
defaultInstructions bool?
getter/setter pair
format String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
instructions Object?
getter/setter pair
jsonSchema Map<String, dynamic>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<GenerateActionOutputConfig>