GenerateMiddlewareDef<CustomOptions> class abstract interface

Properties

configJsonSchema → Map<String, Object?>?
no setter
configSchema → SchemanticType<CustomOptions>?
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(CustomOptions? config, GenerateMiddlewareContext ctx) → GenerateMiddleware
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited