Model<CustomOptions> class

Inheritance
Implemented types

Constructors

Model({required String name, required InternalActionFn<ModelRequest, ModelResponse, ModelResponseChunk, void> fn, Map<String, dynamic>? metadata, SchemanticType<CustomOptions>? customOptions})

Properties

actionType ActionType
finalinherited
config → CustomOptions?
final
customOptions → SchemanticType<CustomOptions>?
final
description String?
finalinherited
fn → InternalActionFn<ModelRequest, ModelResponse, ModelResponseChunk, void>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
initSchema → SchemanticType<void>?
finalinherited
inputSchema → SchemanticType<ModelRequest>?
finalinherited
manifestOutputSchema → SchemanticType?
The output schema surfaced when building action manifests (Dev UI, reflection) and tool definitions.
no setterinherited
metadata Map<String, dynamic>
finalinherited
name String
finalinherited
outputSchema → SchemanticType<ModelResponse>?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamSchema → SchemanticType<ModelResponseChunk>?
finalinherited

Methods

call(ModelRequest? input, {StreamingCallback<ModelResponseChunk>? onChunk, Map<String, dynamic>? context, Stream<ModelRequest>? inputStream, void init, TraceStartCallback? onTraceStart}) Future<ModelResponse>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(ModelRequest? input, {StreamingCallback<ModelResponseChunk>? onChunk, Map<String, dynamic>? context, Stream<ModelRequest>? inputStream, void init, TraceStartCallback? onTraceStart}) Future<RunResult<ModelResponse>>
inherited
runRaw(dynamic input, {StreamingCallback<ModelResponseChunk>? onChunk, Map<String, dynamic>? context, Stream<ModelRequest>? inputStream, dynamic init, TraceStartCallback? onTraceStart}) Future<RunResult<ModelResponse>>
inherited
stream(ModelRequest? input, {Map<String, dynamic>? context, Stream<ModelRequest>? inputStream, void init}) ActionStream<ModelResponseChunk, ModelResponse>
inherited
streamBidi({Stream<ModelRequest>? inputStream, StreamingCallback<ModelResponseChunk>? onChunk, Map<String, dynamic>? context, void init}) → BidiActionStream<ModelResponseChunk, ModelResponse, ModelRequest>
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited