ModelInfo class base

Constructors

ModelInfo({List<String>? versions, String? label, Map<String, dynamic>? configSchema, Map<String, dynamic>? supports, String? stage})
ModelInfo.fromJson(Map<String, dynamic> json)
Creates a ModelInfo from a JSON map.
factory

Properties

configSchema Map<String, dynamic>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
label String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stage String?
getter/setter pair
supports Map<String, dynamic>?
getter/setter pair
versions List<String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ModelInfo to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<ModelInfo>
The JSON schema and type descriptor for ModelInfo.