ModelResponse class base

Available extensions

Constructors

ModelResponse({Message? message, required FinishReason finishReason, String? finishMessage, double? latencyMs, GenerationUsage? usage, Map<String, dynamic>? custom, Map<String, dynamic>? raw, GenerateRequest? request, Operation? operation})
ModelResponse.fromJson(Map<String, dynamic> json)
factory

Properties

custom Map<String, dynamic>?
getter/setter pair
finishMessage String?
getter/setter pair
finishReason FinishReason
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
latencyMs double?
getter/setter pair
media Media?

Available on ModelResponse, provided by the ModelResponseExtension extension

The media content of the response.
no setter
message Message?
getter/setter pair
operation Operation?
getter/setter pair
raw Map<String, dynamic>?
getter/setter pair
request GenerateRequest?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String

Available on ModelResponse, provided by the ModelResponseExtension extension

The text content of the response.
no setter
toolRequests List<ToolRequest>

Available on ModelResponse, provided by the ModelResponseExtension extension

The tool requests in the response.
no setter
usage GenerationUsage?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<ModelResponse>