customPart property
CustomPart?
get
customPart
The custom part if it is one, otherwise null.
Implementation
CustomPart? get customPart => isCustom ? CustomPart.fromJson(toJson()) : null;
The custom part if it is one, otherwise null.
CustomPart? get customPart => isCustom ? CustomPart.fromJson(toJson()) : null;