text property
String?
get
text
The text content if it is a text part, otherwise null.
Implementation
String? get text => textPart?.text;
The text content if it is a text part, otherwise null.
String? get text => textPart?.text;