textPart property
TextPart?
get
textPart
The text part if it is one, otherwise null.
Implementation
TextPart? get textPart => isText ? TextPart.fromJson(toJson()) : null;
The text part if it is one, otherwise null.
TextPart? get textPart => isText ? TextPart.fromJson(toJson()) : null;