toolRequest property
ToolRequest?
get
toolRequest
The tool request content if it is a tool request part, otherwise null.
Implementation
ToolRequest? get toolRequest => toolRequestPart?.toolRequest;
The tool request content if it is a tool request part, otherwise null.
ToolRequest? get toolRequest => toolRequestPart?.toolRequest;