ReflectionSendInputStreamChunkParams class base

Constructors

ReflectionSendInputStreamChunkParams({required String requestId, Map<String, dynamic>? chunk})
ReflectionSendInputStreamChunkParams.fromJson(Map<String, dynamic> json)
Creates a ReflectionSendInputStreamChunkParams from a JSON map.
factory

Properties

chunk Map<String, dynamic>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
requestId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ReflectionSendInputStreamChunkParams to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<ReflectionSendInputStreamChunkParams>
The JSON schema and type descriptor for ReflectionSendInputStreamChunkParams.