RunResult<Output> class final

Constructors

RunResult({required Output result, required String traceId, required String spanId})

Properties

hashCode → int
The hash code for this object.
no setterinherited
result → Output
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spanId → String
final
traceId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited