RuntimeError class base

Constructors

RuntimeError({String? status, required String message, Map<String, dynamic>? details})
RuntimeError.fromJson(Map<String, dynamic> json)
Creates a RuntimeError from a JSON map.
factory

Properties

details ↔ Map<String, dynamic>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this RuntimeError to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<RuntimeError>
The JSON schema and type descriptor for RuntimeError.