SessionState class base

Constructors

SessionState({String? sessionId, List<Message>? messages, Object? custom, List<Artifact>? artifacts})
SessionState.fromJson(Map<String, dynamic> json)
Creates a SessionState from a JSON map.
factory

Properties

artifacts List<Artifact>?
getter/setter pair
custom Object?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
messages List<Message>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this SessionState to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<SessionState>
The JSON schema and type descriptor for SessionState.