ToolDefinition class base

Constructors

ToolDefinition({required String name, String? key, required String description, Map<String, dynamic>? inputSchema, Map<String, dynamic>? outputSchema, Map<String, dynamic>? metadata})
ToolDefinition.fromJson(Map<String, dynamic> json)
Creates a ToolDefinition from a JSON map.
factory

Properties

description ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputSchema ↔ Map<String, dynamic>?
getter/setter pair
key ↔ String?
getter/setter pair
metadata ↔ Map<String, dynamic>?
getter/setter pair
name ↔ String
getter/setter pair
outputSchema ↔ Map<String, dynamic>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ToolDefinition to a JSON map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<ToolDefinition>
The JSON schema and type descriptor for ToolDefinition.