ToolRequestPart class base

Implemented types
Available extensions

Constructors

ToolRequestPart({required ToolRequest toolRequest, Map<String, dynamic>? data, Map<String, dynamic>? metadata, Map<String, dynamic>? custom})
ToolRequestPart.fromJson(Map<String, dynamic> json)
Creates a ToolRequestPart from a JSON map.
factory

Properties

custom ↔ Map<String, dynamic>?
getter/setter pair
custom → Map<String, dynamic>?

Available on Part, provided by the PartExtension extension

The custom content if it is a custom part, otherwise null.
no setter
customPart → CustomPart?

Available on Part, provided by the PartExtension extension

The custom part if it is one, otherwise null.
no setter
data ↔ Map<String, dynamic>?
getter/setter pair
data → Map<String, dynamic>?

Available on Part, provided by the PartExtension extension

The data content if it is a data part, otherwise null.
no setter
dataPart → DataPart?

Available on Part, provided by the PartExtension extension

The data part if it is one, otherwise null.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isCustom → bool

Available on Part, provided by the PartExtension extension

Whether this part is a custom part.
no setter
isData → bool

Available on Part, provided by the PartExtension extension

Whether this part is a data part.
no setter
isMedia → bool

Available on Part, provided by the PartExtension extension

Whether this part is a media part.
no setter
isReasoning → bool

Available on Part, provided by the PartExtension extension

Whether this part is a reasoning part.
no setter
isResource → bool

Available on Part, provided by the PartExtension extension

Whether this part is a resource.
no setter
isText → bool

Available on Part, provided by the PartExtension extension

Whether this part is a text part.
no setter
isToolRequest → bool

Available on Part, provided by the PartExtension extension

Whether this part is a tool request.
no setter
isToolResponse → bool

Available on Part, provided by the PartExtension extension

Whether this part is a tool response.
no setter
media → Media?

Available on Part, provided by the PartExtension extension

The media content if it is a media part, otherwise null.
no setter
mediaPart → MediaPart?

Available on Part, provided by the PartExtension extension

The media part if it is one, otherwise null.
no setter
metadata ↔ Map<String, dynamic>?
getter/setter pair
metadata → Map<String, dynamic>?

Available on Part, provided by the PartExtension extension

The metadata of the part.
no setter
reasoning → String?

Available on Part, provided by the PartExtension extension

The reasoning content if it is a reasoning part, otherwise null.
no setter
reasoningPart → ReasoningPart?

Available on Part, provided by the PartExtension extension

The reasoning part if it is one, otherwise null.
no setter
resource → Map<String, dynamic>?

Available on Part, provided by the PartExtension extension

The resource content if it is a resource part, otherwise null.
no setter
resourcePart → ResourcePart?

Available on Part, provided by the PartExtension extension

The resource part if it is one, otherwise null.
no setter
resumed → dynamic

Available on ToolRequestPart, provided by the ToolRequestPartExtension extension

The resumed payload if this tool request was restarted after an interrupt.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?

Available on Part, provided by the PartExtension extension

The text content if it is a text part, otherwise null.
no setter
textPart → TextPart?

Available on Part, provided by the PartExtension extension

The text part if it is one, otherwise null.
no setter
toolRequest ↔ ToolRequest
getter/setter pair
toolRequest → ToolRequest?

Available on Part, provided by the PartExtension extension

The tool request content if it is a tool request part, otherwise null.
no setter
toolRequestPart → ToolRequestPart?

Available on Part, provided by the PartExtension extension

The tool request part if it is one, otherwise null.
no setter
toolResponse → ToolResponse?

Available on Part, provided by the PartExtension extension

The tool response content if it is a tool response part, otherwise null.
no setter
toolResponsePart → ToolResponsePart?

Available on Part, provided by the PartExtension extension

The tool response part if it is one, otherwise null.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restart(Map<String, dynamic> metadata) → ToolRequestPart

Available on ToolRequestPart, provided by the ToolRequestPartExtension extension

Returns a new ToolRequestPart marked for restart, with the given metadata payload nested under the resumed field.
toJson() → Map<String, dynamic>
Serializes this ToolRequestPart to a JSON map.
override
toString() → String
A string representation of this object.
override
withMetadata(Map<String, dynamic> metadata) → ToolRequestPart

Available on ToolRequestPart, provided by the ToolRequestPartExtension extension

Returns a new ToolRequestPart with the given metadata merged into the existing metadata.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<ToolRequestPart>
The JSON schema and type descriptor for ToolRequestPart.