ToolResponse class base

Constructors

ToolResponse({String? ref, required String name, dynamic output, List? content})
ToolResponse.fromJson(Map<String, dynamic> json)
Creates a ToolResponse from a JSON map.
factory

Properties

content List?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
output ↔ dynamic
getter/setter pair
ref String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ToolResponse to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<ToolResponse>
The JSON schema and type descriptor for ToolResponse.