maxPersistedChainLength property
When set, a chain longer than this is trimmed (oldest first) on each save.
Implementation
final int? maxPersistedChainLength;
When set, a chain longer than this is trimmed (oldest first) on each save.
final int? maxPersistedChainLength;