input property
The action input from the request body, already parsed with the action's
input schema (null when the body has no data).
Implementation
final Object? input;
The action input from the request body, already parsed with the action's
input schema (null when the body has no data).
final Object? input;