GenkitPlugin class abstract

A plugin for Genkit.

Plugin implementers can extend this class and override the methods to provide actions, models, etc.

Implementers

Constructors

GenkitPlugin()

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

init() → Future<List<Action>>
Called when the plugin is initialized.
list() → Future<List<ActionMetadata>>
Called to list actions provided by the plugin.
middleware() → List<GenerateMiddlewareDef>
Middleware provided by the plugin.
model(String name) → Model
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(ActionType actionType, String name) → Action?
Called to resolve an action by name.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited