Registry class

Constructors

Registry({Registry? parent})
Registry.childOf(Registry parent)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
parent Registry?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

listActions() Future<List<ActionMetadata>>
listValues<T>(String type) Map<String, T>
lookupAction(String actionType, String name) Future<Action?>
lookupValue<T>(String type, String name) → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(Action action) → void
registerPlugin(GenkitPlugin plugin) → void
registerValue(String type, String name, dynamic value) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited