$BaseDataPoint class abstract

Annotations
  • @Schema.new()

Constructors

$BaseDataPoint()

Properties

context List<Map<String, dynamic>>?
no setter
hashCode int
The hash code for this object.
no setterinherited
input Map<String, dynamic>?
no setter
output Map<String, dynamic>?
no setter
reference Map<String, dynamic>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
testCaseId String?
no setter
traceIds List<String>?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited