AgentOutput class base

Constructors

AgentOutput({String? sessionId, String? snapshotId, SessionState? state, Message? message, List<Artifact>? artifacts, AgentFinishReason? finishReason, AgentErrorInfo? error})
AgentOutput.fromJson(Map<String, dynamic> json)
Creates a AgentOutput from a JSON map.
factory

Properties

artifacts List<Artifact>?
getter/setter pair
error AgentErrorInfo?
getter/setter pair
finishReason AgentFinishReason?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message Message?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
getter/setter pair
snapshotId String?
getter/setter pair
state SessionState?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this AgentOutput to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<AgentOutput>
The JSON schema and type descriptor for AgentOutput.