AgentTurn<State> class
final
A single in-flight turn — the analog of generateStream's
{stream, response}, plus abort.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
response
→ Future<
AgentResponse< State> > -
The completed turn, with generate-style accessors.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
AgentChunk< State> > -
Chunks as the turn progresses.
final
Methods
-
abort(
) → void - Aborts this in-flight turn.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited