Flow<Input , Output , Chunk , Init > class
base
Constructors
Flow ({required String name , required ActionFn <Input , Output , Chunk , Init > fn , SchemanticType<Input > ? inputSchema , SchemanticType<Output > ? outputSchema , SchemanticType<Chunk > ? streamSchema , SchemanticType<Init > ? initSchema , Map <String , dynamic > ? metadata })
Creates a unary flow.
Flow.bidi ({required String name , required BidiActionFn <Input , Output , Chunk , Init > fn , SchemanticType<Input > ? inputSchema , SchemanticType<Output > ? outputSchema , SchemanticType<Chunk > ? streamSchema , SchemanticType<Init > ? initSchema , Map <String , dynamic > ? metadata })
Creates a bidirectional flow whose function receives the input stream.
Properties
actionType
→ ActionType
final inherited
description
→ String ?
final inherited
hashCode
→ int
The hash code for this object.
no setter inherited
initSchema
→ SchemanticType<Init > ?
final inherited
inputSchema
→ SchemanticType<Input > ?
final inherited
key
→ String ?
The fully-qualified registry key (/$actionType/$name) or, for actions
resolved through a dynamic action provider, the DAP key
(/dynamic-action-provider/<host>:<actionType>/<name>).
no setter inherited
metadata
→ Map <String , dynamic >
final inherited
name
→ String
final inherited
outputSchema
→ SchemanticType<Output > ?
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
streamSchema
→ SchemanticType<Chunk > ?
final inherited
Methods
call (Input? input , {StreamingCallback <Chunk > ? onChunk , Map <String , dynamic > ? context , Stream <Input > ? inputStream , Init? init , TraceStartCallback ? onTraceStart , CancellationToken ? cancel })
→ Future <Output >
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run (Input? input , {StreamingCallback <Chunk > ? onChunk , Map <String , dynamic > ? context , Stream <Input > ? inputStream , Init? init , TraceStartCallback ? onTraceStart , CancellationToken ? cancel })
→ Future <RunResult <Output > >
inherited
runRaw (dynamic input , {StreamingCallback <Chunk > ? onChunk , Map <String , dynamic > ? context , Stream <Input > ? inputStream , dynamic init , TraceStartCallback ? onTraceStart , CancellationToken ? cancel })
→ Future <RunResult <Output > >
inherited
stream (Input? input , {Map <String , dynamic > ? context , Stream <Input > ? inputStream , Init? init , CancellationToken ? cancel })
→ ActionStream <Chunk , Output >
inherited
streamBidi ({Stream <Input > ? inputStream , StreamingCallback <Chunk > ? onChunk , Map <String , dynamic > ? context , Init? init , CancellationToken ? cancel })
→ BidiActionStream <Chunk , Output , Input >
Starts a bidirectional session with this action: send inputs with
BidiActionStream.send while consuming output chunks.
inherited
toJson ()
→ Map <String , dynamic >
inherited
toString ()
→ String
A string representation of this object.
inherited