GenerateResponseHelper<Output> class
final
A response from a generate action.
- Inheritance
-
- Object
- GenerateResponse
- GenerateResponseHelper
Constructors
- GenerateResponseHelper(ModelResponse _response, {ModelRequest? request, Output? output})
Properties
-
candidates
↔ List<
Candidate> ? -
getter/setter pairinherited
-
custom
↔ Map<
String, dynamic> ? -
getter/setter pairinherited
- finishMessage ↔ String?
-
getter/setter pairinherited
- finishReason ↔ FinishReason?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
interrupts
→ List<
ToolRequestPart> -
The list of tool requests that triggered an interrupt.
no setter
- jsonOutput → Output?
-
Tries to parse the output as JSON.
no setter
- latencyMs ↔ double?
-
getter/setter pairinherited
- media → Media?
-
The media content of the response.
no setter
- message ↔ Message?
-
getter/setter pairinherited
-
messages
→ List<
Message> -
The full history of the conversation, including the request messages and
the final model response.
no setter
- modelRequest → ModelRequest?
-
no setter
- modelResponse → ModelResponse
-
no setter
- operation ↔ Operation?
-
getter/setter pairinherited
- output → Output?
-
final
-
raw
↔ Map<
String, dynamic> ? -
getter/setter pairinherited
- rawResponse → ModelResponse
-
no setter
- request ↔ GenerateRequest?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The text content of the response.
no setter
-
toolRequests
→ List<
ToolRequest> -
The tool requests in the response.
no setter
- usage ↔ GenerationUsage?
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this GenerateResponse to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited