InterruptResponse class
A response to an interrupted tool request.
Constructors
- InterruptResponse(ToolRequestPart _part, dynamic output)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
no setter
- output → dynamic
-
final
- ref → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolRequestPart → ToolRequestPart
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited