ModelResponseChunk class base
- Implementers
- Available extensions
Constructors
-
ModelResponseChunk({Role? role, int? index, required List<
Part> content, Map<String, dynamic> ? custom, bool? aggregated}) -
ModelResponseChunk.fromJson(Map<
String, dynamic> json) -
Creates a ModelResponseChunk from a JSON map.
factory
Properties
- aggregated ↔ bool?
-
getter/setter pair
-
content
↔ List<
Part> -
getter/setter pair
-
custom
↔ Map<
String, dynamic> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- index ↔ int?
-
getter/setter pair
- media → Media?
-
Available on ModelResponseChunk, provided by the ModelResponseChunkExtension extension
The media content of the response chunk.no setter - role ↔ Role?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
Available on ModelResponseChunk, provided by the ModelResponseChunkExtension extension
The text content of the response chunk.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes this ModelResponseChunk to a JSON map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
$schema
→ const SchemanticType<
ModelResponseChunk> - The JSON schema and type descriptor for ModelResponseChunk.