ReflectionListActionsResponse class base

Constructors

ReflectionListActionsResponse({required Map<String, dynamic> actions})
ReflectionListActionsResponse.fromJson(Map<String, dynamic> json)
Creates a ReflectionListActionsResponse from a JSON map.
factory

Properties

actions Map<String, dynamic>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ReflectionListActionsResponse to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$schema → const SchemanticType<ReflectionListActionsResponse>
The JSON schema and type descriptor for ReflectionListActionsResponse.